0.9.9 API documentation: GLM_GTX_matrix_factorisation

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_GTX_matrix_factorisation
Experimental extensions

Include <glm/gtx/matrix_factorisation.hpp> to use the features of this extension. More...

## Functions
template<length_t C, length_t R, typename T , qualifier Q>
GLM_FUNC_DECL mat< C, R, T, Q > | fliplr (mat< C, R, T, Q > const &in)
| Flips the matrix columns right and left. More...
template<length_t C, length_t R, typename T , qualifier Q>
GLM_FUNC_DECL mat< C, R, T, Q > | flipud (mat< C, R, T, Q > const &in)
| Flips the matrix rows up and down. More...
template<length_t C, length_t R, typename T , qualifier Q>
GLM_FUNC_DECL void | qr_decompose (mat< C, R, T, Q > const &in, mat<(C< R?C:R), R, T, Q > &q, mat< C,(C< R?C:R), T, Q > &r)
| Performs QR factorisation of a matrix. More...
template<length_t C, length_t R, typename T , qualifier Q>
GLM_FUNC_DECL void | rq_decompose (mat< C, R, T, Q > const &in, mat<(C< R?C:R), R, T, Q > &r, mat< C,(C< R?C:R), T, Q > &q)
| Performs RQ factorisation of a matrix. More...

## Detailed Description

Include <glm/gtx/matrix_factorisation.hpp> to use the features of this extension.

Functions to factor matrices in various forms

## Function Documentation

GLM_FUNC_DECL mat<C, R, T, Q> glm::fliplr | ( | mat< C, R, T, Q > const & | in | ) |

Flips the matrix columns right and left.

From GLM_GTX_matrix_factorisation extension.

GLM_FUNC_DECL mat<C, R, T, Q> glm::flipud | ( | mat< C, R, T, Q > const & | in | ) |

Flips the matrix rows up and down.

From GLM_GTX_matrix_factorisation extension.

GLM_FUNC_DECL void glm::qr_decompose | ( | mat< C, R, T, Q > const & | in | ) |

Performs QR factorisation of a matrix.

Returns 2 matrices, q and r, such that the columns of q are orthonormal and span the same subspace than those of the input matrix, r is an upper triangular matrix, and q*r=in. Given an n-by-m input matrix, q has dimensions min(n,m)-by-m, and r has dimensions n-by-min(n,m).

From GLM_GTX_matrix_factorisation extension.

GLM_FUNC_DECL void glm::rq_decompose | ( | mat< C, R, T, Q > const & | in | ) |

Performs RQ factorisation of a matrix.

Returns 2 matrices, r and q, such that r is an upper triangular matrix, the rows of q are orthonormal and span the same subspace than those of the input matrix, and r*q=in. Note that in the context of RQ factorisation, the diagonal is seen as starting in the lower-right corner of the matrix, instead of the usual upper-left. Given an n-by-m input matrix, r has dimensions min(n,m)-by-m, and q has dimensions n-by-min(n,m).

From GLM_GTX_matrix_factorisation extension.